@@ -23,16 +23,16 @@ from aliyunsdkdbfs.endpoint import endpoint_data
 class DeleteDbfsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'DBFS', '2020-04-18', 'DeleteDbfs')
+		RpcRequest.__init__(self, 'DBFS', '2020-04-18', 'DeleteDbfs','dbfs')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FsId(self):
+	def get_FsId(self): # String
 		return self.get_query_params().get('FsId')
 
-	def set_FsId(self,FsId):
-		self.add_query_param('FsId',FsId)
\ No newline at end of file
+	def set_FsId(self, FsId):  # String
+		self.add_query_param('FsId', FsId)
